@@ -1,6 +1,9 @@
+from typing import Dict, Any, Optional
+
 from dataclass_rest.exceptions import ClientError
 
 from annet.storage import StorageProvider, Storage
+from annet.connectors import AdapterWithName, AdapterWithConfig, T
 from .common.status_client import NetboxStatusClient
 from .common.storage_opts import NetboxStorageOpts
 from .common.query import NetboxQuery
@@ -9,7 +12,7 @@ from .v37.storage import NetboxStorageV37
 
 
 def storage_factory(opts: NetboxStorageOpts) -> Storage:
-    client = NetboxStatusClient(opts.url, opts.token)
+    client = NetboxStatusClient(opts.url, opts.token, opts.insecure)
     try:
         status = client.status()
     except ClientError as e:
@@ -23,7 +26,18 @@ def storage_factory(opts: NetboxStorageOpts) -> Storage:
         raise ValueError(f"Unsupported version: {status.netbox_version}")
 
 
-class NetboxProvider(StorageProvider):
+class NetboxProvider(StorageProvider, AdapterWithName, AdapterWithConfig):
+    def __init__(self, url: Optional[str] = None, token: Optional[str] = None, insecure: bool = False,
+                 exact_host_filter: bool = False):
+        self.url = url
+        self.token = token
+        self.insecure = insecure
+        self.exact_host_filter = exact_host_filter
+
+    @classmethod
+    def with_config(cls, **kwargs: Dict[str, Any]) -> T:
+        return cls(**kwargs)
+
     def storage(self):
         return storage_factory
 
@@ -32,3 +46,7 @@ class NetboxProvider(StorageProvider):
 
     def query(self):
         return NetboxQuery
+
+    @classmethod
+    def name(cls) -> str:
+        return "netbox"
