@@ -1,5 +1,7 @@
 VENDOR_REVERSES = {
     "huawei": "undo",
+    "h3c": "undo",
+    "optixtrans": "undo",
     "cisco": "no",
     "nexus": "no",
     "juniper": "delete",
@@ -9,10 +11,12 @@ VENDOR_REVERSES = {
     "aruba": "no",
     "pc": "-",
     "ribbon": "delete",
+    "b4com": "no",
 }
 
 VENDOR_DIFF = {
     "huawei": "common.default_diff",
+    "optixtrans": "common.default_diff",
     "cisco": "common.default_diff",
     "nexus": "common.default_diff",
     "juniper": "juniper.default_diff",
@@ -22,10 +26,12 @@ VENDOR_DIFF = {
     "aruba": "aruba.default_diff",
     "pc": "common.default_diff",
     "ribbon": "ribbon.default_diff",
+    "b4com": "common.default_diff",
 }
 
 VENDOR_DIFF_ORDERED = {
     "huawei": "common.ordered_diff",
+    "optixtrans": "common.ordered_diff",
     "cisco": "common.ordered_diff",
     "nexus": "common.ordered_diff",
     "juniper": "juniper.ordered_diff",
@@ -35,10 +41,13 @@ VENDOR_DIFF_ORDERED = {
     "aruba": "common.ordered_diff",
     "pc": "common.ordered_diff",
     "ribbon": "ribbon.default_diff",
+    "b4com": "common.ordered_diff",
 }
 
 VENDOR_EXIT = {
     "huawei": "quit",
+    "h3c": "quit",
+    "optixtrans": "quit",
     "cisco": "exit",
     "nexus": "exit",
     "arista": "exit",
@@ -48,4 +57,9 @@ VENDOR_EXIT = {
     "aruba": "exit",
     "pc": "",
     "ribbon": "exit",
+    "b4com": "exit",
+}
+
+VENDOR_ALIASES = {
+    "h3c": "huawei",
 }
