@@ -6,7 +6,7 @@ import sys
 import time
 import warnings
 from collections import OrderedDict as odict
-from itertools import groupby
+from itertools import groupby, chain
 from operator import itemgetter
 from typing import (
     Any,
@@ -35,6 +35,7 @@ from annet import diff as ann_diff
 from annet import filtering
 from annet import gen as ann_gen
 from annet import patching, rulebook, tabparser, tracing
+from annet.rulebook import deploying
 from annet.filtering import Filterer
 from annet.hardware import hardware_connector
 from annet.output import (
@@ -45,7 +46,7 @@ from annet.output import (
 )
 from annet.parallel import Parallel, TaskResult
 from annet.reference import RefTracker
-from annet.storage import Device, storage_connector
+from annet.storage import Device, get_storage
 from annet.types import Diff, ExitCode, OldNewResult, Op, PCDiff, PCDiffFile
 
 
@@ -218,8 +219,8 @@ def log_host_progress_cb(pool: Parallel, task_result: TaskResult):
         stacklevel=2,
     )
     args = cast(cli_args.QueryOptions, pool.args[0])
-    connector = storage_connector.get()
-    storage_opts = connector.opts().from_cli_opts(args)
+    connector = get_storage()
+    storage_opts = connector.opts().parse_params({}, args)
     with connector.storage()(storage_opts) as storage:
         fqdns = storage.resolve_fdnds_by_query(args.query)
     PoolProgressLogger(device_fqdns=fqdns)(pool, task_result)
@@ -260,7 +261,7 @@ def patch(args: cli_args.ShowPatchOptions, loader: ann_gen.Loader):
     """ Сгенерировать патч для устройств """
     global live_configs  # pylint: disable=global-statement
     if args.config == "running":
-        fetcher = annet.deploy.fetcher_connector.get()
+        fetcher = annet.deploy.get_fetcher()
         live_configs = fetcher.fetch(loader.devices, processes=args.parallel)
     stdin = args.stdin(filter_acl=args.filter_acl, config=args.config)
 
@@ -273,12 +274,14 @@ def patch(args: cli_args.ShowPatchOptions, loader: ann_gen.Loader):
 
 def _patch_worker(device_id, args: cli_args.ShowPatchOptions, stdin, loader: ann_gen.Loader, filterer: filtering.Filterer):
     for res, _, patch_tree in res_diff_patch(device_id, args, stdin, loader, filterer):
+        old_files = res.old_files
         new_files = res.get_new_files(args.acl_safe)
         new_json_fragment_files = res.get_new_file_fragments(args.acl_safe)
         if new_files:
             for path, (cfg_text, _cmds) in new_files.items():
                 label = res.device.hostname + os.sep + path
-                yield label, cfg_text, False
+                if old_files.get(path) != cfg_text:
+                    yield label, cfg_text, False
         elif res.old_json_fragment_files or new_json_fragment_files:
             for path, (new_json_cfg, _cmds) in new_json_fragment_files.items():
                 label = res.device.hostname + os.sep + path
@@ -346,7 +349,7 @@ def diff(
         device = res.device
         acl_rules = res.get_acl_rules(args.acl_safe)
         new_files = res.get_new_files(args.acl_safe)
-        new_json_fragment_files = res.get_new_file_fragments()
+        new_json_fragment_files = res.get_new_file_fragments(args.acl_safe)
 
         pc_diff_files = []
         if res.old_files or new_files:
@@ -358,8 +361,14 @@ def diff(
             pc_diff_files.sort(key=lambda f: f.label)
             ret[device] = PCDiff(hostname=device.hostname, diff_files=pc_diff_files)
         elif old is not None:
+            orderer = patching.Orderer.from_hw(device.hw)
             rb = rulebook.get_rulebook(device.hw)
-            diff_tree = patching.make_diff(old, new, rb, [acl_rules, res.filter_acl_rules])
+            diff_tree = patching.make_diff(
+                old,
+                orderer.order_config(new),
+                rb,
+                [acl_rules, res.filter_acl_rules],
+            )
             diff_tree = patching.strip_unchanged(diff_tree)
             ret[device] = diff_tree
 
@@ -434,7 +443,7 @@ class CliDeployerJob(DeployerJob):
         self.cmd_lines.extend(["= %s " % device.hostname, ""])
         self.cmd_lines.extend(map(itemgetter(-1), cmds))
         self.cmd_lines.append("")
-        deployer_driver = annet.deploy.driver_connector.get()
+        deployer_driver = annet.deploy.get_deployer()
         self.deploy_cmds[device] = deployer_driver.apply_deploy_rulebook(
             device.hw, cmds,
             do_commit=not self.args.dont_commit
@@ -461,6 +470,9 @@ class PCDeployerJob(DeployerJob):
         elif not new_files and not new_json_fragment_files:
             return
 
+        enable_reload = self.args.entire_reload is not cli_args.EntireReloadFlag.no
+        force_reload = self.args.entire_reload is cli_args.EntireReloadFlag.force
+
         upload_files: Dict[str, bytes] = {}
         reload_cmds: Dict[str, bytes] = {}
         generator_types: Dict[str, GeneratorType] = {}
@@ -476,33 +488,43 @@ class PCDeployerJob(DeployerJob):
                     old_text = jsontools.format_json(old_json_cfg)
                     new_text = jsontools.format_json(file_content_or_json_cfg)
                     diff_content = "\n".join(_diff_file(old_text, new_text))
-                if diff_content:
-                    self._has_diff = True
-                upload_files[file], reload_cmds[file] = file_content.encode(), cmds.encode()
-                generator_types[file] = generator_type
-                self.cmd_lines.append("= Deploy cmds %s/%s " % (device.hostname, file))
-                self.cmd_lines.extend([cmds, ""])
-                self.cmd_lines.append("= %s/%s " % (device.hostname, file))
-                self.cmd_lines.extend([file_content, ""])
-                self.diff_lines.append("= %s/%s " % (device.hostname, file))
-                self.diff_lines.extend([diff_content, ""])
 
-        if upload_files:
+                if diff_content or force_reload:
+                    self._has_diff |= True
+
+                    upload_files[file] = file_content.encode()
+                    generator_types[file] = generator_type
+                    self.cmd_lines.append("= %s/%s " % (device.hostname, file))
+                    self.cmd_lines.extend([file_content, ""])
+                    self.diff_lines.append("= %s/%s " % (device.hostname, file))
+                    self.diff_lines.extend([diff_content, ""])
+
+                    if enable_reload:
+                        reload_cmds[file] = cmds.encode()
+                        self.cmd_lines.append("= Deploy cmds %s/%s " % (device.hostname, file))
+                        self.cmd_lines.extend([cmds, ""])
+
+        if self._has_diff:
             self.deploy_cmds[device] = {
                 "files": upload_files,
                 "cmds": reload_cmds,
                 "generator_types": generator_types,
             }
             self.diffs[device] = upload_files
-            deployer_driver = annet.deploy.driver_connector.get()
+            deployer_driver = annet.deploy.get_deployer()
             before, after = deployer_driver.build_configuration_cmdlist(device.hw)
             for cmd in deployer_driver.build_exit_cmdlist(device.hw):
                 after.add_cmd(cmd)
             cmds_pre_files = {}
-            for file in self.deploy_cmds[device]["files"]:
-                if before:
-                    cmds_pre_files[file] = "\n".join(map(str, before)).encode(encoding="utf-8")
-                self.deploy_cmds[device]["cmds"][file] += "\n".join(map(str, after)).encode(encoding="utf-8")
+            rules = rulebook.get_rulebook(device.hw)["deploying"]
+            for file, content in self.deploy_cmds[device]["files"].items():
+                rule = deploying.match_deploy_rule(rules, [file], content)
+                before_more, after_more = annet.deploy.make_apply_commands(rule, res.device.hw, do_commit=True, do_finalize=True, path=file)
+
+                cmds_pre_files[file] = "\n".join(map(str, chain(before, before_more))).encode(encoding="utf-8")
+                after_cmds = "\n".join(map(str, chain(after, after_more))).encode(encoding="utf-8")
+                if after_cmds:
+                    self.deploy_cmds[device]["cmds"][file] += b"\n" + after_cmds
             self.deploy_cmds[device]["cmds_pre_files"] = cmds_pre_files
 
 
@@ -522,13 +544,12 @@ class Deployer:
         self._filterer = filtering.filterer_connector.get()
 
     def parse_result(self, job: DeployerJob, result: ann_gen.OldNewResult):
-        entire_reload = self.args.entire_reload
         logger = get_logger(job.device.hostname)
 
         job.parse_result(result)
         self.failed_configs.update(job.failed_configs)
 
-        if job.has_diff() or entire_reload is entire_reload.force:
+        if job.has_diff():
             self.cmd_lines.extend(job.cmd_lines)
             self.deploy_cmds.update(job.deploy_cmds)
             self.diffs.update(job.diffs)
@@ -787,12 +808,20 @@ def guess_hw(config_text: str):
         hw = hw_provider.vendor_to_hw(vendor)
         fmtr = tabparser.make_formatter(hw)
         rb = rulebook.get_rulebook(hw)
-        config = tabparser.parse_to_tree(config_text, fmtr.split)
+        try:
+            config = tabparser.parse_to_tree(config_text, fmtr.split)
+        except Exception:
+            continue
         pre = patching.make_pre(patching.make_diff({}, config, rb, []))
         metric = _count_pre_score(pre)
         scores[metric] = hw
+
+    if not scores:
+        raise RuntimeError("No formatter was guessed")
+
     max_score = max(scores.keys())
     hw = scores[max_score]
+
     return hw, max_score
 
 
