@@ -6,7 +6,7 @@ import itertools
 import re
 from collections import namedtuple
 from contextlib import contextmanager
-from typing import Dict, List, Optional, Type, Any, OrderedDict
+from typing import Dict, List, Optional, Any, OrderedDict, Tuple, Type
 
 from contextlog import get_logger
 
@@ -15,7 +15,7 @@ from annet.annlib.command import Command, Question, CommandList
 from annet.annlib.netdev.views.hardware import HardwareView
 from annet.annlib.rbparser.deploying import MakeMessageMatcher, Answer
 from annet.cli_args import DeployOptions
-from annet.connectors import Connector
+from annet.connectors import Connector, get_connector_from_config
 from annet.output import TextArgs
 from annet.rulebook import get_rulebook, deploying
 from annet.storage import Device
@@ -39,17 +39,23 @@ class DeployResult(_DeployResultBase):  # noqa: E302
 class _FetcherConnector(Connector["Fetcher"]):
     name = "Fetcher"
     ep_name = "deploy_fetcher"
+    ep_by_group_only = "annet.connectors.fetcher"
 
     def _get_default(self) -> Type["Fetcher"]:
-        return StubFetcher
+        # if entry points are broken, try to use direct import
+        import annet.adapters.fetchers.stub.fetcher as stub_fetcher
+        return stub_fetcher.StubFetcher
 
 
 class _DriverConnector(Connector["DeployDriver"]):
     name = "DeployDriver"
     ep_name = "deploy_driver"
+    ep_by_group_only = "annet.connectors.deployer"
 
     def _get_default(self) -> Type["DeployDriver"]:
-        return StubDeployDriver
+        # if entry points are broken, try to use direct import
+        import annet.adapters.deployers.stub.deployer as stub_deployer
+        return stub_deployer.StubDeployDriver
 
 
 fetcher_connector = _FetcherConnector()
@@ -59,7 +65,7 @@ driver_connector = _DriverConnector()
 class Fetcher(abc.ABC):
     @abc.abstractmethod
     def fetch_packages(self, devices: List[Device],
-                       processes: int = 1, max_slots: int = 0):
+                       processes: int = 1, max_slots: int = 0) -> Tuple[Dict[Device, str], Dict[Device, Any]]:
         pass
 
     @abc.abstractmethod
@@ -69,15 +75,10 @@ class Fetcher(abc.ABC):
         pass
 
 
-class StubFetcher(Fetcher):
-    def fetch_packages(self, devices: List[Device],
-                       processes: int = 1, max_slots: int = 0):
-        raise NotImplementedError()
-
-    def fetch(self, devices: List[Device],
-              files_to_download: Dict[str, List[str]] = None,
-              processes: int = 1, max_slots: int = 0):
-        raise NotImplementedError()
+def get_fetcher() -> Fetcher:
+    connectors = fetcher_connector.get_all()
+    fetcher, _ = get_connector_from_config("fetcher", connectors)
+    return fetcher
 
 
 class DeployDriver(abc.ABC):
@@ -86,11 +87,11 @@ class DeployDriver(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def apply_deploy_rulebook(self, hw, cmd_paths, do_finalize=True, do_commit=True):
+    def apply_deploy_rulebook(self, hw: HardwareView, cmd_paths, do_finalize=True, do_commit=True):
         pass
 
     @abc.abstractmethod
-    def build_configuration_cmdlist(self, hw, do_finalize=True, do_commit=True):
+    def build_configuration_cmdlist(self, hw: HardwareView, do_finalize=True, do_commit=True):
         pass
 
     @abc.abstractmethod
@@ -98,18 +99,10 @@ class DeployDriver(abc.ABC):
         pass
 
 
-class StubDeployDriver(DeployDriver):
-    async def bulk_deploy(self, deploy_cmds: dict, args: DeployOptions) -> DeployResult:
-        NotImplementedError()
-
-    def apply_deploy_rulebook(self, hw, cmd_paths, do_finalize=True, do_commit=True):
-        NotImplementedError()
-
-    def build_configuration_cmdlist(self, hw, do_finalize=True, do_commit=True):
-        NotImplementedError()
-
-    def build_exit_cmdlist(self, hw):
-        raise NotImplementedError()
+def get_deployer() -> DeployDriver:
+    connectors = driver_connector.get_all()
+    deployer, _ = get_connector_from_config("deployer", connectors)
+    return deployer
 
 
 # ===
@@ -488,9 +481,9 @@ def make_cmd_params(rule: Dict[str, Any]) -> Dict[str, Any]:
     }
 
 
-def make_apply_commands(rule, hw, do_commit, do_finalize):
+def make_apply_commands(rule: dict, hw: HardwareView, do_commit: bool, do_finalize: bool, path: Optional[str] = None):
     apply_logic = rule["attrs"]["apply_logic"]
-    before, after = apply_logic(hw, do_commit=do_commit, do_finalize=do_finalize)
+    before, after = apply_logic(hw, do_commit=do_commit, do_finalize=do_finalize, path=path)
     return before, after
 
 
