@@ -27,10 +27,9 @@ from contextlog import get_logger
 
 from annet import generators, implicit, patching, tabparser, tracing
 from annet.annlib import jsontools
-from annet.annlib.rbparser import platform
 from annet.annlib.rbparser.acl import compile_acl_text
 from annet.cli_args import DeployOptions, GenOptions, ShowGenOptions
-from annet.deploy import fetcher_connector, scrub_config
+from annet.deploy import scrub_config, get_fetcher
 from annet.filtering import Filterer
 from annet.generators import (
     BaseGenerator,
@@ -407,7 +406,7 @@ def old_new(
     if do_files_download and config == "running":
         files_to_download = _get_files_to_download(devices, gens)
         devices_with_files = [device for device in devices if device in files_to_download]
-        fetcher = fetcher_connector.get()
+        fetcher = get_fetcher()
         fetched_packages, failed_packages = fetcher.fetch_packages(devices_with_files)
 
     ctx = OldNewDeviceContext(
@@ -512,12 +511,11 @@ def worker(device_id, args: ShowGenOptions, stdin, loader: "Loader", filterer: F
         for (path, (data, _)) in sorted(new_file_fragments.items(), key=itemgetter(0)):
             dumped_data = json.dumps(data, indent=4, sort_keys=True, ensure_ascii=False)
             yield (output_driver.entire_config_dest_path(device, path), dumped_data, False)
-
         # Consider result of partial run empty and create an empty dest file
         # only if there are some acl rules that has been matched.
         # Otherwise treat it as if no supported generators have been found.
         acl_rules = res.get_acl_rules(args.acl_safe)
-        if device.hw.vendor in platform.VENDOR_REVERSES and acl_rules:
+        if acl_rules:
             orderer = patching.Orderer.from_hw(device.hw)
             yield (output_driver.cfg_file_names(device)[0],
                    format_config_blocks(
@@ -808,7 +806,7 @@ def _old_resolve_running(config: str, devices: List[Device]) -> Tuple[Dict[Devic
         global live_configs  # pylint: disable=global-statement
         if live_configs is None:
             # предварительно прочесть все конфиги прямо по ssh
-            fetcher = fetcher_connector.get()
+            fetcher = get_fetcher()
             running, failed_running = fetcher.fetch(devices)
         else:
             running, failed_running = live_configs  # pylint: disable=unpacking-non-sequence
@@ -826,7 +824,7 @@ def _old_resolve_files(config: str,
         files_to_download = _get_files_to_download(devices, gens)
         devices_with_files = [device for device in devices if device in files_to_download]
         if devices_with_files:
-            fetcher = fetcher_connector.get()
+            fetcher = get_fetcher()
             downloaded_files, failed_files = fetcher.fetch(devices_with_files,
                                                            files_to_download=files_to_download)
     return downloaded_files, failed_files
@@ -888,3 +886,6 @@ class Loader:
 
     def resolve_gens(self, devices: Iterable[Device]) -> DeviceGenerators:
         return self._gens.for_devices(devices)
+
+    def iter_all_gens(self) -> Iterator[BaseGenerator]:
+        return self._gens.iter_gens()
