@@ -3,6 +3,7 @@ from annet.annlib.tabparser import (  # pylint: disable=unused-import
     CiscoFormatter,
     CommonFormatter,
     HuaweiFormatter,
+    OptixtransFormatter,
     JuniperFormatter,
     JuniperList,
     NokiaFormatter,
@@ -10,16 +11,28 @@ from annet.annlib.tabparser import (  # pylint: disable=unused-import
     RibbonFormatter,
     RosFormatter,
     parse_to_tree,
+    AristaFormatter,
+    NexusFormatter,
+    B4comFormatter,
+    ArubaFormatter,
 )
 
 
 def make_formatter(hw, **kwargs):
-    if hw.Huawei:
+    if hw.OptiXtrans:
+        cls = OptixtransFormatter
+    elif hw.Huawei:
         cls = HuaweiFormatter
     elif hw.Cisco.ASR or hw.Cisco.XRV:
         cls = AsrFormatter
-    elif hw.Nexus or hw.Cisco or hw.Arista or hw.Aruba:
+    elif hw.Nexus:
+        cls = NexusFormatter
+    elif hw.Cisco:
         cls = CiscoFormatter
+    elif hw.B4com:
+        cls = B4comFormatter
+    elif hw.Aruba:
+        cls = ArubaFormatter
     elif hw.Juniper:
         cls = JuniperFormatter
     elif hw.Nokia:
@@ -30,6 +43,10 @@ def make_formatter(hw, **kwargs):
         cls = CommonFormatter
     elif hw.Ribbon:
         cls = RibbonFormatter
+    elif hw.H3C:
+        cls = HuaweiFormatter
+    elif hw.Arista:
+        cls = AristaFormatter
     else:
         raise NotImplementedError("Unknown formatter for hw '%s'" % hw)
 
